@@ -10,12 +10,6 @@ import click
 
 DEBUG = False
 
-# Enable -h flag, rather than just --help
-# REF: https://click.palletsprojects.com/en/7.x/documentation/#help-parameter-customization
-CLICK_CTX_CONFIG = dict(
-    help_option_names=["-h", "--help"],
-)
-
 Command = str | list[str]
 
 
@@ -24,7 +18,7 @@ class WorkflowType(Enum):
     FORK = "fork"
 
 
-@click.group(context_settings=CLICK_CTX_CONFIG)
+@click.group(context_settings=dict(help_option_names=["-h", "--help"]))
 @click.version_option()
 def cli():
     pass
@@ -32,9 +26,10 @@ def cli():
 
 @cli.command()
 @click.argument("target", required=False)
-# no update
+@click.option("-c", "--carry", is_flag=True, default=False, help="Carry current changes to the new stack.")
+@click.option("-m", "--main", is_flag=True, default=False, help="Stay on main, don't switch back to target.")
 @click.option("-n", "--no-update", is_flag=True, default=False, help="Do not update main.")
-def hack(target: str, no_update: bool) -> None:
+def hack(target: str, carry: bool, main: bool, no_update: bool) -> None:
     """
     Update main and optionally create a new stack.
 
@@ -54,9 +49,14 @@ def hack(target: str, no_update: bool) -> None:
     main_branch = main_branch_name()
 
     # Validate
-    if try_run("git status --porcelain"):
-        cexit("current branch is dirty, aborting")
+    dirty_changes = try_run("git status --porcelain")
+    if dirty_changes:
+        if carry:
+            must_run("git stash push --include-untracked", loud=True)
+        else:
+            cexit("current branch is dirty, aborting")
     start = current_branch()
+    target = target or start or (main_branch if main else None)  # default to current branch, else main if --main
     if not start and not target:
         cexit("start and target branches empty (detached head and no target), aborting")
     validate_branches()
@@ -72,18 +72,17 @@ def hack(target: str, no_update: bool) -> None:
         else:
             must_run("git pull", loud=True)
 
-    # Just updating main, so ensure ending on the starting branch
-    if not target or target == main_branch:
-        if start != main_branch:
-            must_run(f"git checkout {start}", loud=True)
-        return
+    # Create/switch to stack
+    if target != main_branch and not main:
+        if create_target:
+            must_run(f"git branch {target}_base", loud=True)
+            must_run(f"git checkout -b {target}", loud=True)
+        else:
+            must_run(f"git checkout {target}", loud=True)
 
-    # Create/switch to new stack
-    if create_target:
-        must_run(f"git branch {target}_base", loud=True)
-        must_run(f"git checkout -b {target}", loud=True)
-    else:
-        must_run(f"git checkout {target}", loud=True)
+    # Carry changes
+    if carry:
+        must_run("git stash pop", loud=True)
 
 
 @cli.command()
@@ -336,19 +335,19 @@ def validate_branches(target: str = "") -> None:
 
 def validate_target_hack_branch(target: str, main_branch: str) -> bool:
     """Validate the target branch for the hack command. Returns True iff the target needs to be created."""
-    if not target or target == main_branch:
+    if target == main_branch:
         return False
 
     target_exists = branch_exists(target)
     target_base_exists = branch_exists(f"{target}_base")
+
+    if not target_exists and not target_base_exists:
+        return True
     if target_exists and not target_base_exists:
         cexit(f"ERROR: target branch '{target}' exists, but base branch '{target}_base' does not, aborting")
     if not target_exists and target_base_exists:
         cexit(f"ERROR: base branch '{target}_base' exists, but target branch '{target}' does not, aborting")
-    if target_exists and target_base_exists:
-        log(f"WARNING: stack '{target}' already exists")
-        return False
-    return True
+    return False
 
 
 def strip_suffix(s: str, suffix: str) -> str:
